/*
 * SPDX-License-Identifier: BSD-3-Clause
 *
 * Copyright © 2024 Keith Packard
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* This file is auto-generated from mkctype.py */
/* clang-format off */

{ 0x0000, CLASS_cntrl },
{ 0x0009, CLASS_blank|CLASS_cntrl|CLASS_space },
{ 0x000a, CLASS_cntrl|CLASS_space },
{ 0x000e, CLASS_cntrl },
{ 0x0020, CLASS_blank|CLASS_print|CLASS_space },
{ 0x0021, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0030, CLASS_alnum|CLASS_digit|CLASS_graph|CLASS_print|CLASS_xdigit },
{ 0x003a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0041, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_xdigit },
{ 0x0047, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x005b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0061, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_xdigit },
{ 0x0067, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x007b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x007f, CLASS_cntrl },
{ 0x00a0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00aa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x00ab, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00b5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x00b6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00ba, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x00bb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x00d7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00d8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x00df, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x00e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x00f7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x00f8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0138, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0139, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0149, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x014a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x018d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x018e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01aa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x01ac, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01ba, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x01bb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x01bc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01be, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x01bf, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x01c4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01c5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_case },
{ 0x01c6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01c8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_case },
{ 0x01c9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01cb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_case },
{ 0x01cc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x01f1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x01f2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case|CLASS_case },
{ 0x01f3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0221, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0222, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0234, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x023a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0255, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0256, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0258, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0259, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x025a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x025b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x025d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0260, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0262, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0263, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0267, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0268, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x026d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x026f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0270, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0271, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0273, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0275, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0276, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x027d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x027e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0280, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0281, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0282, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0284, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0287, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x028d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0292, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0293, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0294, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0295, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x029d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x029f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x02b9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x02c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x02c2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x02c6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x02d2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x02e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x02e5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x02ec, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x02ed, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x02ee, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x02ef, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0345, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0346, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0363, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0370, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0374, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0375, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0376, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0378, CLASS_none },
{ 0x037a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x037b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x037e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x037f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0380, CLASS_none },
{ 0x0384, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0386, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0387, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0388, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x038b, CLASS_none },
{ 0x038c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x038d, CLASS_none },
{ 0x038e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0390, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0391, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x03a2, CLASS_none },
{ 0x03a3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x03b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x03b1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x03d2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x03d5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x03f6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x03f7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x03fc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x03fd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0482, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x048a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0530, CLASS_none },
{ 0x0531, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0557, CLASS_none },
{ 0x0559, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x055a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0560, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0561, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x0587, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x0589, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x058b, CLASS_none },
{ 0x058d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0590, CLASS_none },
{ 0x0591, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05be, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05bf, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05c1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05c3, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05c4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05c6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05c7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05c8, CLASS_none },
{ 0x05d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05eb, CLASS_none },
{ 0x05ef, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x05f3, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x05f5, CLASS_none },
{ 0x0600, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0610, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x061b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0620, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0658, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0659, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x066a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x066e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x06d4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x06d5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x06dd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x06e1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x06e9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x06ed, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x06fd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x06ff, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0700, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x070e, CLASS_none },
{ 0x070f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0710, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0740, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x074b, CLASS_none },
{ 0x074d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x07b2, CLASS_none },
{ 0x07c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x07eb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x07f4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x07f6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x07fa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x07fb, CLASS_none },
{ 0x07fd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0818, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x081a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x082d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x082e, CLASS_none },
{ 0x0830, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x083f, CLASS_none },
{ 0x0840, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0859, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x085c, CLASS_none },
{ 0x085e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x085f, CLASS_none },
{ 0x0860, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x086b, CLASS_none },
{ 0x0870, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0888, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0889, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x088f, CLASS_none },
{ 0x0890, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0892, CLASS_none },
{ 0x0897, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0898, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x08a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x08ca, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x08d4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x08e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x08e3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x08ea, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x08f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x093c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x093d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x094d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x094e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0951, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0955, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0964, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0966, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0970, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0971, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0984, CLASS_none },
{ 0x0985, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x098d, CLASS_none },
{ 0x098f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0991, CLASS_none },
{ 0x0993, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09a9, CLASS_none },
{ 0x09aa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09b1, CLASS_none },
{ 0x09b2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09b3, CLASS_none },
{ 0x09b6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09ba, CLASS_none },
{ 0x09bc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x09bd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09c5, CLASS_none },
{ 0x09c7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09c9, CLASS_none },
{ 0x09cb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09cd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x09ce, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09cf, CLASS_none },
{ 0x09d7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09d8, CLASS_none },
{ 0x09dc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09de, CLASS_none },
{ 0x09df, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09e4, CLASS_none },
{ 0x09e6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09f2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x09fc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x09fd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x09ff, CLASS_none },
{ 0x0a01, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a04, CLASS_none },
{ 0x0a05, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a0b, CLASS_none },
{ 0x0a0f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a11, CLASS_none },
{ 0x0a13, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a29, CLASS_none },
{ 0x0a2a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a31, CLASS_none },
{ 0x0a32, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a34, CLASS_none },
{ 0x0a35, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a37, CLASS_none },
{ 0x0a38, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a3a, CLASS_none },
{ 0x0a3c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0a3d, CLASS_none },
{ 0x0a3e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a43, CLASS_none },
{ 0x0a47, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a49, CLASS_none },
{ 0x0a4b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a4d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0a4e, CLASS_none },
{ 0x0a51, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a52, CLASS_none },
{ 0x0a59, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a5d, CLASS_none },
{ 0x0a5e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a5f, CLASS_none },
{ 0x0a66, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a76, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0a77, CLASS_none },
{ 0x0a81, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a84, CLASS_none },
{ 0x0a85, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a8e, CLASS_none },
{ 0x0a8f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0a92, CLASS_none },
{ 0x0a93, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0aa9, CLASS_none },
{ 0x0aaa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ab1, CLASS_none },
{ 0x0ab2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ab4, CLASS_none },
{ 0x0ab5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0aba, CLASS_none },
{ 0x0abc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0abd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ac6, CLASS_none },
{ 0x0ac7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0aca, CLASS_none },
{ 0x0acb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0acd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0ace, CLASS_none },
{ 0x0ad0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ad1, CLASS_none },
{ 0x0ae0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ae4, CLASS_none },
{ 0x0ae6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0af0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0af2, CLASS_none },
{ 0x0af9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0afd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b00, CLASS_none },
{ 0x0b01, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b04, CLASS_none },
{ 0x0b05, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b0d, CLASS_none },
{ 0x0b0f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b11, CLASS_none },
{ 0x0b13, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b29, CLASS_none },
{ 0x0b2a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b31, CLASS_none },
{ 0x0b32, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b34, CLASS_none },
{ 0x0b35, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b3a, CLASS_none },
{ 0x0b3c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b3d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b45, CLASS_none },
{ 0x0b47, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b49, CLASS_none },
{ 0x0b4b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b4d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b4e, CLASS_none },
{ 0x0b55, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b56, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b58, CLASS_none },
{ 0x0b5c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b5e, CLASS_none },
{ 0x0b5f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b64, CLASS_none },
{ 0x0b66, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b70, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b71, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b72, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0b78, CLASS_none },
{ 0x0b82, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b84, CLASS_none },
{ 0x0b85, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b8b, CLASS_none },
{ 0x0b8e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b91, CLASS_none },
{ 0x0b92, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b96, CLASS_none },
{ 0x0b99, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b9b, CLASS_none },
{ 0x0b9c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0b9d, CLASS_none },
{ 0x0b9e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ba0, CLASS_none },
{ 0x0ba3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ba5, CLASS_none },
{ 0x0ba8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bab, CLASS_none },
{ 0x0bae, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bba, CLASS_none },
{ 0x0bbe, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bc3, CLASS_none },
{ 0x0bc6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bc9, CLASS_none },
{ 0x0bca, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bcd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0bce, CLASS_none },
{ 0x0bd0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bd1, CLASS_none },
{ 0x0bd7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bd8, CLASS_none },
{ 0x0be6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0bf0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0bfb, CLASS_none },
{ 0x0c00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c0d, CLASS_none },
{ 0x0c0e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c11, CLASS_none },
{ 0x0c12, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c29, CLASS_none },
{ 0x0c2a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c3a, CLASS_none },
{ 0x0c3c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0c3d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c45, CLASS_none },
{ 0x0c46, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c49, CLASS_none },
{ 0x0c4a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c4d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0c4e, CLASS_none },
{ 0x0c55, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c57, CLASS_none },
{ 0x0c58, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c5b, CLASS_none },
{ 0x0c5d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c5e, CLASS_none },
{ 0x0c60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c64, CLASS_none },
{ 0x0c66, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c70, CLASS_none },
{ 0x0c77, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0c80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c84, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0c85, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c8d, CLASS_none },
{ 0x0c8e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0c91, CLASS_none },
{ 0x0c92, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ca9, CLASS_none },
{ 0x0caa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cb4, CLASS_none },
{ 0x0cb5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cba, CLASS_none },
{ 0x0cbc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0cbd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cc5, CLASS_none },
{ 0x0cc6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cc9, CLASS_none },
{ 0x0cca, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ccd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0cce, CLASS_none },
{ 0x0cd5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cd7, CLASS_none },
{ 0x0cdd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cdf, CLASS_none },
{ 0x0ce0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ce4, CLASS_none },
{ 0x0ce6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cf0, CLASS_none },
{ 0x0cf1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0cf4, CLASS_none },
{ 0x0d00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d0d, CLASS_none },
{ 0x0d0e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d11, CLASS_none },
{ 0x0d12, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d3b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0d3d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d45, CLASS_none },
{ 0x0d46, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d49, CLASS_none },
{ 0x0d4a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d4d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0d4e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d4f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0d50, CLASS_none },
{ 0x0d54, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d58, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0d5f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d64, CLASS_none },
{ 0x0d66, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d70, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0d7a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d80, CLASS_none },
{ 0x0d81, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d84, CLASS_none },
{ 0x0d85, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0d97, CLASS_none },
{ 0x0d9a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0db2, CLASS_none },
{ 0x0db3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0dbc, CLASS_none },
{ 0x0dbd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0dbe, CLASS_none },
{ 0x0dc0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0dc7, CLASS_none },
{ 0x0dca, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0dcb, CLASS_none },
{ 0x0dcf, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0dd5, CLASS_none },
{ 0x0dd6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0dd7, CLASS_none },
{ 0x0dd8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0de0, CLASS_none },
{ 0x0de6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0df0, CLASS_none },
{ 0x0df2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0df4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0df5, CLASS_none },
{ 0x0e01, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e3b, CLASS_none },
{ 0x0e3f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0e40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e47, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0e4d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e4e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0e50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e5a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0e5c, CLASS_none },
{ 0x0e81, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e83, CLASS_none },
{ 0x0e84, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e85, CLASS_none },
{ 0x0e86, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0e8b, CLASS_none },
{ 0x0e8c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ea4, CLASS_none },
{ 0x0ea5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ea6, CLASS_none },
{ 0x0ea7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0eba, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0ebb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ebe, CLASS_none },
{ 0x0ec0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ec5, CLASS_none },
{ 0x0ec6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ec7, CLASS_none },
{ 0x0ec8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0ecd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ece, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0ecf, CLASS_none },
{ 0x0ed0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0eda, CLASS_none },
{ 0x0edc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0ee0, CLASS_none },
{ 0x0f00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f01, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0f20, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f2a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0f40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f48, CLASS_none },
{ 0x0f49, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f6d, CLASS_none },
{ 0x0f71, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f84, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0f88, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0f98, CLASS_none },
{ 0x0f99, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x0fbd, CLASS_none },
{ 0x0fbe, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0fcd, CLASS_none },
{ 0x0fce, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x0fdb, CLASS_none },
{ 0x1000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1037, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1038, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1039, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x103b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x104a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1050, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x109e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10c6, CLASS_none },
{ 0x10c7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10c8, CLASS_none },
{ 0x10cd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10ce, CLASS_none },
{ 0x10d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10fb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10fc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x10fd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1100, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1249, CLASS_none },
{ 0x124a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x124e, CLASS_none },
{ 0x1250, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1257, CLASS_none },
{ 0x1258, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1259, CLASS_none },
{ 0x125a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x125e, CLASS_none },
{ 0x1260, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1289, CLASS_none },
{ 0x128a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x128e, CLASS_none },
{ 0x1290, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12b1, CLASS_none },
{ 0x12b2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12b6, CLASS_none },
{ 0x12b8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12bf, CLASS_none },
{ 0x12c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12c1, CLASS_none },
{ 0x12c2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12c6, CLASS_none },
{ 0x12c8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12d7, CLASS_none },
{ 0x12d8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1311, CLASS_none },
{ 0x1312, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1316, CLASS_none },
{ 0x1318, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x135b, CLASS_none },
{ 0x135d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x137d, CLASS_none },
{ 0x1380, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1390, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x139a, CLASS_none },
{ 0x13a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x13f6, CLASS_none },
{ 0x13f8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x13fe, CLASS_none },
{ 0x1400, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1401, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x166d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x166f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1680, CLASS_blank|CLASS_print|CLASS_space },
{ 0x1681, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x169b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x169d, CLASS_none },
{ 0x16a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16eb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16ee, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16f9, CLASS_none },
{ 0x1700, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1714, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1716, CLASS_none },
{ 0x171f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1734, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1737, CLASS_none },
{ 0x1740, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1754, CLASS_none },
{ 0x1760, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x176d, CLASS_none },
{ 0x176e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1771, CLASS_none },
{ 0x1772, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1774, CLASS_none },
{ 0x1780, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x17b4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x17b6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x17c9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x17d7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x17d8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x17dc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x17dd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x17de, CLASS_none },
{ 0x17e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x17ea, CLASS_none },
{ 0x17f0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x17fa, CLASS_none },
{ 0x1800, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1810, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x181a, CLASS_none },
{ 0x1820, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1879, CLASS_none },
{ 0x1880, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x18ab, CLASS_none },
{ 0x18b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x18f6, CLASS_none },
{ 0x1900, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x191f, CLASS_none },
{ 0x1920, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x192c, CLASS_none },
{ 0x1930, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1939, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x193c, CLASS_none },
{ 0x1940, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1941, CLASS_none },
{ 0x1944, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1946, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x196e, CLASS_none },
{ 0x1970, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1975, CLASS_none },
{ 0x1980, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x19ac, CLASS_none },
{ 0x19b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x19ca, CLASS_none },
{ 0x19d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x19da, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x19db, CLASS_none },
{ 0x19de, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1a00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1a1c, CLASS_none },
{ 0x1a1e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1a20, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1a5f, CLASS_none },
{ 0x1a60, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1a61, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1a75, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1a7d, CLASS_none },
{ 0x1a7f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1a80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1a8a, CLASS_none },
{ 0x1a90, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1a9a, CLASS_none },
{ 0x1aa0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1aa7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1aa8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1aae, CLASS_none },
{ 0x1ab0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1abf, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ac1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1acc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1acf, CLASS_none },
{ 0x1b00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b34, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1b35, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b44, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1b45, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b4d, CLASS_none },
{ 0x1b4e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1b50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b5a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1b80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1baa, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1bac, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1be6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1be7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bf2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1bf4, CLASS_none },
{ 0x1bfc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1c00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1c37, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1c38, CLASS_none },
{ 0x1c3b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1c40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1c4a, CLASS_none },
{ 0x1c4d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1c7e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1c80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1c8b, CLASS_none },
{ 0x1c90, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1cbb, CLASS_none },
{ 0x1cbd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1cc0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cc8, CLASS_none },
{ 0x1cd0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ce9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ced, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cee, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1cf4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cf5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1cf7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cfa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1cfb, CLASS_none },
{ 0x1d00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d79, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1d7a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d7d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1d7e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d8e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1d8f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1dc0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1dd3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1df5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1e96, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1e9b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1e9c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1e9e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1e9f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1ea0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f16, CLASS_none },
{ 0x1f18, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f1e, CLASS_none },
{ 0x1f20, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f46, CLASS_none },
{ 0x1f48, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f4e, CLASS_none },
{ 0x1f50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1f51, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f52, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1f53, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f54, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1f55, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f56, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1f57, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f58, CLASS_none },
{ 0x1f59, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f5a, CLASS_none },
{ 0x1f5b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f5c, CLASS_none },
{ 0x1f5d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f5e, CLASS_none },
{ 0x1f5f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1f7e, CLASS_none },
{ 0x1f80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fb2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fb3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fb4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fb5, CLASS_none },
{ 0x1fb6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fb8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fbd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fbe, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fbf, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fc2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fc3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fc4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fc5, CLASS_none },
{ 0x1fc6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fc8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fcd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fd0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fd2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fd4, CLASS_none },
{ 0x1fd6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fd8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fdc, CLASS_none },
{ 0x1fdd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fe0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fe2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fe5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fe6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1fe8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1fed, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ff0, CLASS_none },
{ 0x1ff2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1ff3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1ff4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1ff5, CLASS_none },
{ 0x1ff6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1ff8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1ffd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fff, CLASS_none },
{ 0x2000, CLASS_blank|CLASS_print|CLASS_space },
{ 0x2007, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2008, CLASS_blank|CLASS_print|CLASS_space },
{ 0x200b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2028, CLASS_cntrl|CLASS_space },
{ 0x202a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x205f, CLASS_blank|CLASS_print|CLASS_space },
{ 0x2060, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2065, CLASS_none },
{ 0x2066, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2071, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2072, CLASS_none },
{ 0x2074, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x207f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2080, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x208f, CLASS_none },
{ 0x2090, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x209d, CLASS_none },
{ 0x20a0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x20c1, CLASS_none },
{ 0x20d0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x20f1, CLASS_none },
{ 0x2100, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2102, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2103, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2107, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2108, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x210a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x210b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x210e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2110, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2113, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2114, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2115, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2116, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2119, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x211e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2124, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2125, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2126, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2127, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2128, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2129, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x212a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x212c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x212e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x212f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2130, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2132, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2133, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2134, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2135, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2139, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x213a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x213c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x213e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2140, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2145, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x2146, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x214a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x214e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x214f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2160, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2180, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2183, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2185, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2189, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x218c, CLASS_none },
{ 0x2190, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x242a, CLASS_none },
{ 0x2440, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x244b, CLASS_none },
{ 0x2460, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x24b6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x24ea, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2b74, CLASS_none },
{ 0x2b76, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2b96, CLASS_none },
{ 0x2b97, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2c00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2c71, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2c72, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2c74, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2c75, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2c77, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2c7e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2ce4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x2ce5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2ceb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2cef, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2cf2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2cf4, CLASS_none },
{ 0x2cf9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2d00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2d26, CLASS_none },
{ 0x2d27, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2d28, CLASS_none },
{ 0x2d2d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x2d2e, CLASS_none },
{ 0x2d30, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2d68, CLASS_none },
{ 0x2d6f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2d70, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2d71, CLASS_none },
{ 0x2d7f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2d80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2d97, CLASS_none },
{ 0x2da0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2da7, CLASS_none },
{ 0x2da8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2daf, CLASS_none },
{ 0x2db0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2db7, CLASS_none },
{ 0x2db8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2dbf, CLASS_none },
{ 0x2dc0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2dc7, CLASS_none },
{ 0x2dc8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2dcf, CLASS_none },
{ 0x2dd0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2dd7, CLASS_none },
{ 0x2dd8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2ddf, CLASS_none },
{ 0x2de0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2e00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2e2f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2e30, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2e5e, CLASS_none },
{ 0x2e80, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2e9a, CLASS_none },
{ 0x2e9b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2ef4, CLASS_none },
{ 0x2f00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x2fd6, CLASS_none },
{ 0x2ff0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3000, CLASS_blank|CLASS_print|CLASS_space },
{ 0x3001, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3005, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3008, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3021, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x302a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3031, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3036, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3038, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x303d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3040, CLASS_none },
{ 0x3041, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3097, CLASS_none },
{ 0x3099, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x309d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x30a0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x30a1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x30fb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x30fc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3100, CLASS_none },
{ 0x3105, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3130, CLASS_none },
{ 0x3131, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x318f, CLASS_none },
{ 0x3190, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x31a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x31c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x31e6, CLASS_none },
{ 0x31ef, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x31f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3200, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x321f, CLASS_none },
{ 0x3220, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x3400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x4dc0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x4e00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa48d, CLASS_none },
{ 0xa490, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa4c7, CLASS_none },
{ 0xa4d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa4fe, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa500, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa60d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa610, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa62c, CLASS_none },
{ 0xa640, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa66e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa66f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa674, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa67c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa67f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa680, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa69c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa69e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa6f0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa6f8, CLASS_none },
{ 0xa700, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa717, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa720, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa722, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa730, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa732, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa770, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa779, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa788, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa789, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa78b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa78e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa78f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa790, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa795, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa796, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa7af, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa7b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa7ce, CLASS_none },
{ 0xa7d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa7d2, CLASS_none },
{ 0xa7d3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa7d4, CLASS_none },
{ 0xa7d5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa7d6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa7dd, CLASS_none },
{ 0xa7f2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa7f5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xa7f7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa7f8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xa7fb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa806, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa807, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa828, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa82d, CLASS_none },
{ 0xa830, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa83a, CLASS_none },
{ 0xa840, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa874, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa878, CLASS_none },
{ 0xa880, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa8c4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa8c5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa8c6, CLASS_none },
{ 0xa8ce, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa8d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa8da, CLASS_none },
{ 0xa8e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa8f2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa8f8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa8fb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa8fc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa8fd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa92b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa930, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa953, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa954, CLASS_none },
{ 0xa95f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa960, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa97d, CLASS_none },
{ 0xa980, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa9b3, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa9b4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa9c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa9ce, CLASS_none },
{ 0xa9cf, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa9da, CLASS_none },
{ 0xa9de, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xa9e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xa9ff, CLASS_none },
{ 0xaa00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaa37, CLASS_none },
{ 0xaa40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaa4e, CLASS_none },
{ 0xaa50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaa5a, CLASS_none },
{ 0xaa5c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaa60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaa77, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaa7a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaabf, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaac0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaac1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaac2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaac3, CLASS_none },
{ 0xaadb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaade, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaae0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaaf0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaaf2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xaaf6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xaaf7, CLASS_none },
{ 0xab01, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xab07, CLASS_none },
{ 0xab09, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xab0f, CLASS_none },
{ 0xab11, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xab17, CLASS_none },
{ 0xab20, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xab27, CLASS_none },
{ 0xab28, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xab2f, CLASS_none },
{ 0xab30, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xab53, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xab54, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xab5b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xab5c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xab6a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xab6c, CLASS_none },
{ 0xab70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xabc0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xabeb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xabee, CLASS_none },
{ 0xabf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xabfa, CLASS_none },
{ 0xac00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xd7a4, CLASS_none },
{ 0xd7b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xd7c7, CLASS_none },
{ 0xd7cb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xd7fc, CLASS_none },
{ 0xe000, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xf900, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfa6e, CLASS_none },
{ 0xfa70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfada, CLASS_none },
{ 0xfb00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xfb07, CLASS_none },
{ 0xfb13, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0xfb18, CLASS_none },
{ 0xfb1d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb29, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfb2a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb37, CLASS_none },
{ 0xfb38, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb3d, CLASS_none },
{ 0xfb3e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb3f, CLASS_none },
{ 0xfb40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb42, CLASS_none },
{ 0xfb43, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfb45, CLASS_none },
{ 0xfb46, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfbb2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfbc3, CLASS_none },
{ 0xfbd3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfd3e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfd50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfd90, CLASS_none },
{ 0xfd92, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfdc8, CLASS_none },
{ 0xfdcf, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfdd0, CLASS_none },
{ 0xfdf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfdfc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfe1a, CLASS_none },
{ 0xfe20, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfe53, CLASS_none },
{ 0xfe54, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfe67, CLASS_none },
{ 0xfe68, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xfe6c, CLASS_none },
{ 0xfe70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfe75, CLASS_none },
{ 0xfe76, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xfefd, CLASS_none },
{ 0xfeff, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xff00, CLASS_none },
{ 0xff01, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xff10, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xff1a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xff21, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xff3b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xff41, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0xff5b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xff66, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xffbf, CLASS_none },
{ 0xffc2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xffc8, CLASS_none },
{ 0xffca, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xffd0, CLASS_none },
{ 0xffd2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xffd8, CLASS_none },
{ 0xffda, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0xffdd, CLASS_none },
{ 0xffe0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xffe7, CLASS_none },
{ 0xffe8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xffef, CLASS_none },
{ 0xfff9, CLASS_graph|CLASS_print|CLASS_punct },
#if __SIZEOF_WCHAR_T__ == 2
{ 0xfffe, CLASS_none },
#else
{ 0xfffe, CLASS_none },
{ 0x10000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1000c, CLASS_none },
{ 0x1000d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10027, CLASS_none },
{ 0x10028, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1003b, CLASS_none },
{ 0x1003c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1003e, CLASS_none },
{ 0x1003f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1004e, CLASS_none },
{ 0x10050, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1005e, CLASS_none },
{ 0x10080, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x100fb, CLASS_none },
{ 0x10100, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10103, CLASS_none },
{ 0x10107, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10134, CLASS_none },
{ 0x10137, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10140, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10175, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1018f, CLASS_none },
{ 0x10190, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1019d, CLASS_none },
{ 0x101a0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x101a1, CLASS_none },
{ 0x101d0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x101fe, CLASS_none },
{ 0x10280, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1029d, CLASS_none },
{ 0x102a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x102d1, CLASS_none },
{ 0x102e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x102fc, CLASS_none },
{ 0x10300, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10320, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10324, CLASS_none },
{ 0x1032d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1034b, CLASS_none },
{ 0x10350, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1037b, CLASS_none },
{ 0x10380, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1039e, CLASS_none },
{ 0x1039f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x103a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x103c4, CLASS_none },
{ 0x103c8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x103d0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x103d1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x103d6, CLASS_none },
{ 0x10400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10450, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1049e, CLASS_none },
{ 0x104a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x104aa, CLASS_none },
{ 0x104b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x104d4, CLASS_none },
{ 0x104d8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x104fc, CLASS_none },
{ 0x10500, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10528, CLASS_none },
{ 0x10530, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10564, CLASS_none },
{ 0x1056f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10570, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1057b, CLASS_none },
{ 0x1057c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1058b, CLASS_none },
{ 0x1058c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10593, CLASS_none },
{ 0x10594, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10596, CLASS_none },
{ 0x10597, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x105a2, CLASS_none },
{ 0x105a3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x105b2, CLASS_none },
{ 0x105b3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x105ba, CLASS_none },
{ 0x105bb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x105bd, CLASS_none },
{ 0x105c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x105f4, CLASS_none },
{ 0x10600, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10737, CLASS_none },
{ 0x10740, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10756, CLASS_none },
{ 0x10760, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10768, CLASS_none },
{ 0x10780, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x10781, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10783, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x10786, CLASS_none },
{ 0x10787, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x107b1, CLASS_none },
{ 0x107b2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x107bb, CLASS_none },
{ 0x10800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10806, CLASS_none },
{ 0x10808, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10809, CLASS_none },
{ 0x1080a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10836, CLASS_none },
{ 0x10837, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10839, CLASS_none },
{ 0x1083c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1083d, CLASS_none },
{ 0x1083f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10856, CLASS_none },
{ 0x10857, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10860, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10877, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10880, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1089f, CLASS_none },
{ 0x108a7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x108b0, CLASS_none },
{ 0x108e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x108f3, CLASS_none },
{ 0x108f4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x108f6, CLASS_none },
{ 0x108fb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10900, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10916, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1091c, CLASS_none },
{ 0x1091f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10920, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1093a, CLASS_none },
{ 0x1093f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10940, CLASS_none },
{ 0x10980, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x109b8, CLASS_none },
{ 0x109bc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x109be, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x109c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x109d0, CLASS_none },
{ 0x109d2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a04, CLASS_none },
{ 0x10a05, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a07, CLASS_none },
{ 0x10a0c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a14, CLASS_none },
{ 0x10a15, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a18, CLASS_none },
{ 0x10a19, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a36, CLASS_none },
{ 0x10a38, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a3b, CLASS_none },
{ 0x10a3f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a49, CLASS_none },
{ 0x10a50, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a59, CLASS_none },
{ 0x10a60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a7d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10a80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10a9d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10aa0, CLASS_none },
{ 0x10ac0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10ac8, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10ac9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10ae5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10ae7, CLASS_none },
{ 0x10aeb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10af7, CLASS_none },
{ 0x10b00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10b36, CLASS_none },
{ 0x10b39, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10b40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10b56, CLASS_none },
{ 0x10b58, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10b60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10b73, CLASS_none },
{ 0x10b78, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10b80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10b92, CLASS_none },
{ 0x10b99, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10b9d, CLASS_none },
{ 0x10ba9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10bb0, CLASS_none },
{ 0x10c00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10c49, CLASS_none },
{ 0x10c80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10cb3, CLASS_none },
{ 0x10cc0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10cf3, CLASS_none },
{ 0x10cfa, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10d00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10d28, CLASS_none },
{ 0x10d30, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10d3a, CLASS_none },
{ 0x10d40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10d50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10d66, CLASS_none },
{ 0x10d69, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10d6a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10d6f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10d70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x10d86, CLASS_none },
{ 0x10d8e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10d90, CLASS_none },
{ 0x10e60, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10e7f, CLASS_none },
{ 0x10e80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10eaa, CLASS_none },
{ 0x10eab, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10ead, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10eae, CLASS_none },
{ 0x10eb0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10eb2, CLASS_none },
{ 0x10ec2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10ec5, CLASS_none },
{ 0x10efc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10efd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10f00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10f1d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10f27, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10f28, CLASS_none },
{ 0x10f30, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10f46, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10f5a, CLASS_none },
{ 0x10f70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10f82, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10f8a, CLASS_none },
{ 0x10fb0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10fc5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x10fcc, CLASS_none },
{ 0x10fe0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x10ff7, CLASS_none },
{ 0x11000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11046, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1104e, CLASS_none },
{ 0x11052, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11066, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11070, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11071, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11076, CLASS_none },
{ 0x1107f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11080, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x110b9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x110c2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x110c3, CLASS_none },
{ 0x110cd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x110ce, CLASS_none },
{ 0x110d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x110e9, CLASS_none },
{ 0x110f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x110fa, CLASS_none },
{ 0x11100, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11133, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11135, CLASS_none },
{ 0x11136, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11140, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11144, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11148, CLASS_none },
{ 0x11150, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11173, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11176, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11177, CLASS_none },
{ 0x11180, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x111c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x111c1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x111c5, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x111ce, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x111db, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x111dc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x111dd, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x111e0, CLASS_none },
{ 0x111e1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x111f5, CLASS_none },
{ 0x11200, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11212, CLASS_none },
{ 0x11213, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11235, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11237, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11238, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1123e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11242, CLASS_none },
{ 0x11280, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11287, CLASS_none },
{ 0x11288, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11289, CLASS_none },
{ 0x1128a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1128e, CLASS_none },
{ 0x1128f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1129e, CLASS_none },
{ 0x1129f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x112a9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x112aa, CLASS_none },
{ 0x112b0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x112e9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x112eb, CLASS_none },
{ 0x112f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x112fa, CLASS_none },
{ 0x11300, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11304, CLASS_none },
{ 0x11305, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1130d, CLASS_none },
{ 0x1130f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11311, CLASS_none },
{ 0x11313, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11329, CLASS_none },
{ 0x1132a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11331, CLASS_none },
{ 0x11332, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11334, CLASS_none },
{ 0x11335, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1133a, CLASS_none },
{ 0x1133b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1133d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11345, CLASS_none },
{ 0x11347, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11349, CLASS_none },
{ 0x1134b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1134d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1134e, CLASS_none },
{ 0x11350, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11351, CLASS_none },
{ 0x11357, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11358, CLASS_none },
{ 0x1135d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11364, CLASS_none },
{ 0x11366, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1136d, CLASS_none },
{ 0x11370, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11375, CLASS_none },
{ 0x11380, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1138a, CLASS_none },
{ 0x1138b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1138c, CLASS_none },
{ 0x1138e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1138f, CLASS_none },
{ 0x11390, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113b6, CLASS_none },
{ 0x113b7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113c1, CLASS_none },
{ 0x113c2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113c3, CLASS_none },
{ 0x113c5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113c6, CLASS_none },
{ 0x113c7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113cb, CLASS_none },
{ 0x113cc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113ce, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x113d1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113d2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x113d3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x113d4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x113d6, CLASS_none },
{ 0x113d7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x113d9, CLASS_none },
{ 0x113e1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x113e3, CLASS_none },
{ 0x11400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11442, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11443, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11446, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11447, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1144b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11450, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1145a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1145c, CLASS_none },
{ 0x1145d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1145f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11462, CLASS_none },
{ 0x11480, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x114c2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x114c4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x114c6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x114c7, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x114c8, CLASS_none },
{ 0x114d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x114da, CLASS_none },
{ 0x11580, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x115b6, CLASS_none },
{ 0x115b8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x115bf, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x115d8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x115de, CLASS_none },
{ 0x11600, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1163f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11640, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11641, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11644, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11645, CLASS_none },
{ 0x11650, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1165a, CLASS_none },
{ 0x11660, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1166d, CLASS_none },
{ 0x11680, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x116b6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x116b8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x116b9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x116ba, CLASS_none },
{ 0x116c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x116ca, CLASS_none },
{ 0x116d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x116e4, CLASS_none },
{ 0x11700, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1171b, CLASS_none },
{ 0x1171d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1172b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1172c, CLASS_none },
{ 0x11730, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1173a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11740, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11747, CLASS_none },
{ 0x11800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11839, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1183c, CLASS_none },
{ 0x118a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x118e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x118ea, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x118f3, CLASS_none },
{ 0x118ff, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11907, CLASS_none },
{ 0x11909, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1190a, CLASS_none },
{ 0x1190c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11914, CLASS_none },
{ 0x11915, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11917, CLASS_none },
{ 0x11918, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11936, CLASS_none },
{ 0x11937, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11939, CLASS_none },
{ 0x1193b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1193d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1193f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11943, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11947, CLASS_none },
{ 0x11950, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1195a, CLASS_none },
{ 0x119a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x119a8, CLASS_none },
{ 0x119aa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x119d8, CLASS_none },
{ 0x119da, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x119e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x119e1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x119e2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x119e3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x119e5, CLASS_none },
{ 0x11a00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11a33, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11a35, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11a3f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11a48, CLASS_none },
{ 0x11a50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11a98, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11a9d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11a9e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11aa3, CLASS_none },
{ 0x11ab0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11af9, CLASS_none },
{ 0x11b00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11b0a, CLASS_none },
{ 0x11bc0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11be1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11be2, CLASS_none },
{ 0x11bf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11bfa, CLASS_none },
{ 0x11c00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c09, CLASS_none },
{ 0x11c0a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c37, CLASS_none },
{ 0x11c38, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c3f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11c40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c41, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11c46, CLASS_none },
{ 0x11c50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c5a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11c6d, CLASS_none },
{ 0x11c70, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11c72, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11c90, CLASS_none },
{ 0x11c92, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11ca8, CLASS_none },
{ 0x11ca9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11cb7, CLASS_none },
{ 0x11d00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d07, CLASS_none },
{ 0x11d08, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d0a, CLASS_none },
{ 0x11d0b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d37, CLASS_none },
{ 0x11d3a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d3b, CLASS_none },
{ 0x11d3c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d3e, CLASS_none },
{ 0x11d3f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d42, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11d43, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d44, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11d46, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d48, CLASS_none },
{ 0x11d50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d5a, CLASS_none },
{ 0x11d60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d66, CLASS_none },
{ 0x11d67, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d69, CLASS_none },
{ 0x11d6a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d8f, CLASS_none },
{ 0x11d90, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d92, CLASS_none },
{ 0x11d93, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d97, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11d98, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11d99, CLASS_none },
{ 0x11da0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11daa, CLASS_none },
{ 0x11ee0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11ef7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11ef9, CLASS_none },
{ 0x11f00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11f11, CLASS_none },
{ 0x11f12, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11f3b, CLASS_none },
{ 0x11f3e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11f41, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11f50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11f5a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11f5b, CLASS_none },
{ 0x11fb0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x11fb1, CLASS_none },
{ 0x11fc0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x11ff2, CLASS_none },
{ 0x11fff, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x12000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1239a, CLASS_none },
{ 0x12400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1246f, CLASS_none },
{ 0x12470, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x12475, CLASS_none },
{ 0x12480, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12544, CLASS_none },
{ 0x12f90, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x12ff1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x12ff3, CLASS_none },
{ 0x13000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x13430, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x13441, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x13447, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x13456, CLASS_none },
{ 0x13460, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x143fb, CLASS_none },
{ 0x14400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x14647, CLASS_none },
{ 0x16100, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1612f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16130, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1613a, CLASS_none },
{ 0x16800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16a39, CLASS_none },
{ 0x16a40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16a5f, CLASS_none },
{ 0x16a60, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16a6a, CLASS_none },
{ 0x16a6e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16a70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16abf, CLASS_none },
{ 0x16ac0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16aca, CLASS_none },
{ 0x16ad0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16aee, CLASS_none },
{ 0x16af0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16af6, CLASS_none },
{ 0x16b00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16b30, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16b40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16b44, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16b46, CLASS_none },
{ 0x16b50, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16b5a, CLASS_none },
{ 0x16b5b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16b62, CLASS_none },
{ 0x16b63, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16b78, CLASS_none },
{ 0x16b7d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16b90, CLASS_none },
{ 0x16d40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16d6d, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16d70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16d7a, CLASS_none },
{ 0x16e40, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x16e80, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16e9b, CLASS_none },
{ 0x16f00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16f4b, CLASS_none },
{ 0x16f4f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16f88, CLASS_none },
{ 0x16f8f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16fa0, CLASS_none },
{ 0x16fe0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16fe2, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16fe3, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16fe4, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x16fe5, CLASS_none },
{ 0x16ff0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x16ff2, CLASS_none },
{ 0x17000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x187f8, CLASS_none },
{ 0x18800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x18cd6, CLASS_none },
{ 0x18cff, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x18d09, CLASS_none },
{ 0x1aff0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1aff4, CLASS_none },
{ 0x1aff5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1affc, CLASS_none },
{ 0x1affd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1afff, CLASS_none },
{ 0x1b000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b123, CLASS_none },
{ 0x1b132, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b133, CLASS_none },
{ 0x1b150, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b153, CLASS_none },
{ 0x1b155, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b156, CLASS_none },
{ 0x1b164, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b168, CLASS_none },
{ 0x1b170, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1b2fc, CLASS_none },
{ 0x1bc00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bc6b, CLASS_none },
{ 0x1bc70, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bc7d, CLASS_none },
{ 0x1bc80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bc89, CLASS_none },
{ 0x1bc90, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bc9a, CLASS_none },
{ 0x1bc9c, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1bc9e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1bc9f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1bca4, CLASS_none },
{ 0x1cc00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ccf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ccfa, CLASS_none },
{ 0x1cd00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ceb4, CLASS_none },
{ 0x1cf00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cf2e, CLASS_none },
{ 0x1cf30, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cf47, CLASS_none },
{ 0x1cf50, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1cfc4, CLASS_none },
{ 0x1d000, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d0f6, CLASS_none },
{ 0x1d100, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d127, CLASS_none },
{ 0x1d129, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d1eb, CLASS_none },
{ 0x1d200, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d246, CLASS_none },
{ 0x1d2c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d2d4, CLASS_none },
{ 0x1d2e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d2f4, CLASS_none },
{ 0x1d300, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d357, CLASS_none },
{ 0x1d360, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d379, CLASS_none },
{ 0x1d400, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d41a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d434, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d44e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d455, CLASS_none },
{ 0x1d456, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d468, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d482, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d49c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d49d, CLASS_none },
{ 0x1d49e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4a0, CLASS_none },
{ 0x1d4a2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4a3, CLASS_none },
{ 0x1d4a5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4a7, CLASS_none },
{ 0x1d4a9, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4ad, CLASS_none },
{ 0x1d4ae, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4b6, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d4ba, CLASS_none },
{ 0x1d4bb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d4bc, CLASS_none },
{ 0x1d4bd, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d4c4, CLASS_none },
{ 0x1d4c5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d4d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d4ea, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d504, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d506, CLASS_none },
{ 0x1d507, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d50b, CLASS_none },
{ 0x1d50d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d515, CLASS_none },
{ 0x1d516, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d51d, CLASS_none },
{ 0x1d51e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d538, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d53a, CLASS_none },
{ 0x1d53b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d53f, CLASS_none },
{ 0x1d540, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d545, CLASS_none },
{ 0x1d546, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d547, CLASS_none },
{ 0x1d54a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d551, CLASS_none },
{ 0x1d552, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d56c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d586, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d5a0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d5ba, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d5d4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d5ee, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d608, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d622, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d63c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d656, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d670, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d68a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d6a6, CLASS_none },
{ 0x1d6a8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d6c1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d6c2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d6db, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d6dc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d6e2, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d6fb, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d6fc, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d715, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d716, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d71c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d735, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d736, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d74f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d750, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d756, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d76f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d770, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d789, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d78a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d790, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d7a9, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d7aa, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d7c3, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1d7c4, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d7ca, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1d7cb, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1d7cc, CLASS_none },
{ 0x1d7ce, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1d800, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1da8c, CLASS_none },
{ 0x1da9b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1daa0, CLASS_none },
{ 0x1daa1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1dab0, CLASS_none },
{ 0x1df00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1df0a, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1df0b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1df1f, CLASS_none },
{ 0x1df25, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1df2b, CLASS_none },
{ 0x1e000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e007, CLASS_none },
{ 0x1e008, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e019, CLASS_none },
{ 0x1e01b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e022, CLASS_none },
{ 0x1e023, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e025, CLASS_none },
{ 0x1e026, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e02b, CLASS_none },
{ 0x1e030, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_lower },
{ 0x1e06e, CLASS_none },
{ 0x1e08f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e090, CLASS_none },
{ 0x1e100, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e12d, CLASS_none },
{ 0x1e130, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e137, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e13e, CLASS_none },
{ 0x1e140, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e14a, CLASS_none },
{ 0x1e14e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e14f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e150, CLASS_none },
{ 0x1e290, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e2ae, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e2af, CLASS_none },
{ 0x1e2c0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e2ec, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e2f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e2fa, CLASS_none },
{ 0x1e2ff, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e300, CLASS_none },
{ 0x1e4d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e4ec, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e4f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e4fa, CLASS_none },
{ 0x1e5d0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e5ee, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e5f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e5fb, CLASS_none },
{ 0x1e5ff, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e600, CLASS_none },
{ 0x1e7e0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e7e7, CLASS_none },
{ 0x1e7e8, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e7ec, CLASS_none },
{ 0x1e7ed, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e7ef, CLASS_none },
{ 0x1e7f0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e7ff, CLASS_none },
{ 0x1e800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e8c5, CLASS_none },
{ 0x1e8c7, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e8d7, CLASS_none },
{ 0x1e900, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_case },
{ 0x1e944, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e947, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e948, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e94b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e94c, CLASS_none },
{ 0x1e950, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1e95a, CLASS_none },
{ 0x1e95e, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1e960, CLASS_none },
{ 0x1ec71, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ecb5, CLASS_none },
{ 0x1ed01, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1ed3e, CLASS_none },
{ 0x1ee00, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee04, CLASS_none },
{ 0x1ee05, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee20, CLASS_none },
{ 0x1ee21, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee23, CLASS_none },
{ 0x1ee24, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee25, CLASS_none },
{ 0x1ee27, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee28, CLASS_none },
{ 0x1ee29, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee33, CLASS_none },
{ 0x1ee34, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee38, CLASS_none },
{ 0x1ee39, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee3a, CLASS_none },
{ 0x1ee3b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee3c, CLASS_none },
{ 0x1ee42, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee43, CLASS_none },
{ 0x1ee47, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee48, CLASS_none },
{ 0x1ee49, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee4a, CLASS_none },
{ 0x1ee4b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee4c, CLASS_none },
{ 0x1ee4d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee50, CLASS_none },
{ 0x1ee51, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee53, CLASS_none },
{ 0x1ee54, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee55, CLASS_none },
{ 0x1ee57, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee58, CLASS_none },
{ 0x1ee59, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee5a, CLASS_none },
{ 0x1ee5b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee5c, CLASS_none },
{ 0x1ee5d, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee5e, CLASS_none },
{ 0x1ee5f, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee60, CLASS_none },
{ 0x1ee61, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee63, CLASS_none },
{ 0x1ee64, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee65, CLASS_none },
{ 0x1ee67, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee6b, CLASS_none },
{ 0x1ee6c, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee73, CLASS_none },
{ 0x1ee74, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee78, CLASS_none },
{ 0x1ee79, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee7d, CLASS_none },
{ 0x1ee7e, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee7f, CLASS_none },
{ 0x1ee80, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee8a, CLASS_none },
{ 0x1ee8b, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1ee9c, CLASS_none },
{ 0x1eea1, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1eea4, CLASS_none },
{ 0x1eea5, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1eeaa, CLASS_none },
{ 0x1eeab, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1eebc, CLASS_none },
{ 0x1eef0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1eef2, CLASS_none },
{ 0x1f000, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f02c, CLASS_none },
{ 0x1f030, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f094, CLASS_none },
{ 0x1f0a0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f0af, CLASS_none },
{ 0x1f0b1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f0c0, CLASS_none },
{ 0x1f0c1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f0d0, CLASS_none },
{ 0x1f0d1, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f0f6, CLASS_none },
{ 0x1f100, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f130, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1f14a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f150, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1f16a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f170, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print|CLASS_upper },
{ 0x1f18a, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f1ae, CLASS_none },
{ 0x1f1e6, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f203, CLASS_none },
{ 0x1f210, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f23c, CLASS_none },
{ 0x1f240, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f249, CLASS_none },
{ 0x1f250, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f252, CLASS_none },
{ 0x1f260, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f266, CLASS_none },
{ 0x1f300, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f6d8, CLASS_none },
{ 0x1f6dc, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f6ed, CLASS_none },
{ 0x1f6f0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f6fd, CLASS_none },
{ 0x1f700, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f777, CLASS_none },
{ 0x1f77b, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f7da, CLASS_none },
{ 0x1f7e0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f7ec, CLASS_none },
{ 0x1f7f0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f7f1, CLASS_none },
{ 0x1f800, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f80c, CLASS_none },
{ 0x1f810, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f848, CLASS_none },
{ 0x1f850, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f85a, CLASS_none },
{ 0x1f860, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f888, CLASS_none },
{ 0x1f890, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f8ae, CLASS_none },
{ 0x1f8b0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f8bc, CLASS_none },
{ 0x1f8c0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1f8c2, CLASS_none },
{ 0x1f900, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fa54, CLASS_none },
{ 0x1fa60, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fa6e, CLASS_none },
{ 0x1fa70, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fa7d, CLASS_none },
{ 0x1fa80, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fa8a, CLASS_none },
{ 0x1fa8f, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fac7, CLASS_none },
{ 0x1face, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fadd, CLASS_none },
{ 0x1fadf, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1faea, CLASS_none },
{ 0x1faf0, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1faf9, CLASS_none },
{ 0x1fb00, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fb93, CLASS_none },
{ 0x1fb94, CLASS_graph|CLASS_print|CLASS_punct },
{ 0x1fbf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x1fbfa, CLASS_none },
{ 0x20000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2a6e0, CLASS_none },
{ 0x2a700, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2b73a, CLASS_none },
{ 0x2b740, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2b81e, CLASS_none },
{ 0x2b820, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2cea2, CLASS_none },
{ 0x2ceb0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2ebe1, CLASS_none },
{ 0x2ebf0, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2ee5e, CLASS_none },
{ 0x2f800, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x2fa1e, CLASS_none },
{ 0x30000, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x3134b, CLASS_none },
{ 0x31350, CLASS_alnum|CLASS_alpha|CLASS_graph|CLASS_print },
{ 0x323b0, CLASS_none },
{ 0xe0001, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xe0002, CLASS_none },
{ 0xe0020, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xe0080, CLASS_none },
{ 0xe0100, CLASS_graph|CLASS_print|CLASS_punct },
{ 0xe01f0, CLASS_none },
#endif
